@@ -3,7 +3,6 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <errno.h>
-#include <signal.h>
 #include <stdlib.h>
 #include <assert.h>
 
@@ -17,24 +16,6 @@
 
 const char* FILE_NAME = "Sys/Process.c";
 
-int32_t SPVM__Sys__Process__alarm(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef _WIN32
-  env->die(env, stack, "alarm is not supported on this system", FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
-#else
-  (void)env;
-  (void)stack;
-  
-  int32_t seconds = stack[0].ival;
-  
-  int32_t rest_time = alarm(seconds);
-  
-  stack[0].ival = rest_time;
-  
-  return 0;
-#endif
-}
-
 int32_t SPVM__Sys__Process__fork(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
   env->die(env, stack, "fork is not supported on this system", FILE_NAME, __LINE__);
@@ -117,29 +98,6 @@ int32_t SPVM__Sys__Process__sleep(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__Process__kill(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef _WIN32
-  env->die(env, stack, "kill is not supported on this system", FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
-#else
-  (void)env;
-  (void)stack;
-  
-  int32_t pid = stack[0].ival;
-  int32_t sig = stack[1].ival;
-  
-  int32_t status = kill(pid, sig);
-  if (status == -1) {
-    env->die(env, stack, "[System Error]kill failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-#endif
-}
-
 int32_t SPVM__Sys__Process__wait(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
   env->die(env, stack, "wait is not supported on this system", FILE_NAME, __LINE__);
@@ -489,23 +447,3 @@ int32_t SPVM__Sys__Process__usleep(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__Process__ualarm(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef _WIN32
-  env->die(env, stack, "ualarm is not supported on this system", FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
-#else
-  (void)env;
-  (void)stack;
-  
-  int64_t usecs = stack[0].lval;
-
-  int64_t interval = stack[1].lval;
-  
-  int32_t rest_usecs = ualarm(usecs, interval);
-  
-  stack[0].lval = rest_usecs;
-  
-  return 0;
-#endif
-}
-
